package com.ruoyi.frequency.ordermessage.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ruoyi.controller.resp.MessageOrderPageResp;
import com.ruoyi.frequency.ordermessage.entity.OrderMessage;
import com.ruoyi.frequency.ordermessage.entity.OrderMessageUtil;
import com.ruoyi.vo.UserVo;
import org.apache.ibatis.annotations.Param;

/**
 * 订单消息Mapper接口
 * 
 * @author zj
 * @date 2023-10-13
 */
public interface OrderMessageMapper  extends BaseMapper<OrderMessage>
{
    /**
     * 查询订单消息
     * 
     * @param id 订单消息主键
     * @return 订单消息
     */
    public OrderMessage selectOrderMessageById(Long id);

    /**
     * 查询订单消息列表
     * 
     * @param orderMessage 订单消息
     * @return 订单消息集合
     */
    public List<OrderMessage> selectOrderMessageList(OrderMessage orderMessage);

    /**
     * 新增订单消息
     * 
     * @param orderMessage 订单消息
     * @return 结果
     */
    public int insertOrderMessage(OrderMessage orderMessage);

    /**
     * 修改订单消息
     * 
     * @param orderMessageUtil 订单消息
     * @return 结果
     */
    public int updateOrderMessage(OrderMessage orderMessage);

    /**
     * 删除订单消息
     * 
     * @param id 订单消息主键
     * @return 结果
     */
    public int deleteOrderMessageById(Long id);

    /**
     * 批量删除订单消息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteOrderMessageByIds(Long[] ids);

    Page<MessageOrderPageResp> messageOrderPage(@Param("page") Page<Object> page, @Param("userVo") UserVo userVo);
}
